@@ -269,7 +269,7 @@ int32 Redraw::fillActorDrawingList(DrawListStruct *drawList, bool flagflip) {
 				drawList[drawListPos].offset = 1;
 				drawListPos++;
 			}
-			if (_inSceneryView && a == _engine->_scene->_currentlyFollowedActor) {
+			if (_flagMCGA && a == _engine->_scene->_currentlyFollowedActor) {
 				_sceneryViewX = projPos.x;
 				_sceneryViewY = projPos.y;
 			}
@@ -871,10 +871,6 @@ void Redraw::redrawEngineActions(bool bgRedraw) { // AffScene
 		}
 		_engine->_screens->_fadePalette = false;
 	}
-
-	if (_inSceneryView) {
-		zoomScreenScale();
-	}
 }
 
 void Redraw::drawBubble(int32 actorIdx) {
@@ -909,17 +905,4 @@ void Redraw::drawBubble(int32 actorIdx) {
 	}
 }
 
-void Redraw::zoomScreenScale() {
-	Graphics::ManagedSurface zoomWorkVideoBuffer(_engine->_workVideoBuffer);
-	const int maxW = zoomWorkVideoBuffer.w;
-	const int maxH = zoomWorkVideoBuffer.h;
-	const int left = CLIP<int>(_sceneryViewX - maxW / 4, 0, maxW / 2);
-	const int top = CLIP<int>(_sceneryViewY - maxH / 4, 0, maxH / 2);
-	const Common::Rect srcRect(left, top, left + maxW / 2, top + maxH / 2);
-	const Common::Rect& destRect = zoomWorkVideoBuffer.getBounds();
-	zoomWorkVideoBuffer.transBlitFrom(_engine->_frontVideoBuffer, srcRect, destRect);
-	g_system->copyRectToScreen(zoomWorkVideoBuffer.getPixels(), zoomWorkVideoBuffer.pitch, 0, 0, zoomWorkVideoBuffer.w, zoomWorkVideoBuffer.h);
-	g_system->updateScreen();
-}
-
 } // namespace TwinE
